@@ -53,6 +53,7 @@ import java.util.List;
 import org.glassfish.grizzly.comet.CometContext;
 import com.openexchange.drive.DriveSession;
 import com.openexchange.drive.events.DriveEvent;
+import com.openexchange.drive.events.subscribe.SubscriptionMode;
 import com.openexchange.drive.json.LongPollingListener;
 import com.openexchange.drive.json.LongPollingListenerFactory;
 
@@ -79,8 +80,8 @@ public class CometListenerFactory implements LongPollingListenerFactory {
     }
 
     @Override
-    public LongPollingListener create(DriveSession session, List<String> rootFolderIDs) {
-        return new CometListener(session, cometContext, rootFolderIDs);
+    public LongPollingListener create(DriveSession session, List<String> rootFolderIDs, SubscriptionMode mode) {
+        return new CometListener(session, cometContext, rootFolderIDs, mode);
     }
 
     @Override
